@@ -105,6 +105,11 @@ return [
 			'url' => '/api/accounts/{id}/quota',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'accounts#testAccountConnection',
+			'url' => '/api/accounts/{id}/test',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'autoConfig#queryIspdb',
 			'url' => '/api/autoconfig/ispdb/{email}',
@@ -130,6 +135,11 @@ return [
 			'url' => '/api/tags/{id}',
 			'verb' => 'PUT'
 		],
+		[
+			'name' => 'tags#delete',
+			'url' => '/api/tags/{accountId}/delete/{id}',
+			'verb' => 'DELETE'
+		],
 		[
 			'name' => 'aliases#updateSignature',
 			'url' => '/api/accounts/{accountId}/aliases/{id}/signature',
@@ -260,6 +270,11 @@ return [
 			'url' => '/api/messages/{id}/snooze',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'messages#unSnooze',
+			'url' => '/api/messages/{id}/unsnooze',
+			'verb' => 'POST'
+		],
 		[
 			'name' => 'messages#mdn',
 			'url' => '/api/messages/{id}/mdn',
@@ -375,6 +390,11 @@ return [
 			'url' => '/api/thread/{id}/snooze',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'thread#unSnooze',
+			'url' => '/api/thread/{id}/unsnooze',
+			'verb' => 'POST'
+		],
 		[
 			'name' => 'thread#summarize',
 			'url' => '/api/thread/{id}/summary',
@@ -430,7 +450,21 @@ return [
 			'url' => '/api/drafts/move/{id}',
 			'verb' => 'POST',
 		],
-
+		[
+			'name' => 'outOfOffice#getState',
+			'url' => '/api/out-of-office/{accountId}',
+			'verb' => 'GET',
+		],
+		[
+			'name' => 'outOfOffice#update',
+			'url' => '/api/out-of-office/{accountId}',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'outOfOffice#followSystem',
+			'url' => '/api/out-of-office/{accountId}/follow-system',
+			'verb' => 'POST',
+		],
 	],
 	'resources' => [
 		'accounts' => ['url' => '/api/accounts'],
